@@ -4,18 +4,21 @@ use strict;
 use warnings;
 use base qw(DateTime::Format::Natural::Base);
 
-use Carp ();
+use Carp qw(croak);
 use DateTime ();
-use Date::Calc qw(Day_of_Week);
+use Date::Calc qw(Day_of_Week check_date);
 use List::MoreUtils qw(all any);
+use Params::Validate ':all';
 
-our $VERSION = '0.68_01';
+our $VERSION = '0.71_01';
 
 sub new
 {
     my $class = shift;
 
     my $self = bless {}, ref($class) || $class;
+
+    $self->_init_check(@_);
     $self->_init(@_);
 
     return $self;
@@ -31,8 +34,6 @@ sub _init
     $self->{Time_zone}     = $opts{time_zone}     || 'floating';
     $self->{Opts}{daytime} = $opts{daytime};
 
-    $self->_init_check;
-
     my $mod = __PACKAGE__.'::Lang::'.uc($self->{Lang});
     eval "use $mod"; die $@ if $@;
 
@@ -44,32 +45,48 @@ sub _init_check
 {
     my $self = shift;
 
-    my %re = (format        => qr!^(?:[dmy]{1,4}[-./]){2}[dmy]{1,4}$!i,
-              lang          => qr!^(?:en)$!,
-              prefer_future => qr!^(?:0|1)$!);
+    validation_options(
+        on_fail => sub
+    {
+        my ($error) = @_;
+        chomp $error;
+        croak $error;
+    },
+        stack_skip => 2,
+    );
 
-    my %msg = (format        => 'format string has no valid format',
-               lang          => 'language is not supported',
-               prefer_future => 'must be a boolean');
-
-    my $error;
-    foreach my $lookup (keys %re) {
-        my $param = ucfirst $lookup;
-        unless ($self->{$param} =~ $re{$lookup}) {
-            $error = "parameter '$lookup': $msg{$lookup}";
-            last;
-        }
-    }
-    Carp::croak "new(): `$error'" if defined $error;
-
-    # time zone can't easily be checked by a regex
-    eval {
-        DateTime::TimeZone->new(name => $self->{Time_zone});
-    };
-    if ($@) {
-        chomp(my $tz_error = $@);
-        Carp::croak "new(): `$tz_error'";
-    }
+    validate(@_, {
+        lang => {
+            type => SCALAR,
+            optional => 1,
+            regex => qr!^(?:en)$!,
+        },
+        format => {
+            type => SCALAR,
+            optional => 1,
+            regex => qr!^(?:[dmy]{1,4}[-./]){2}[dmy]{1,4}$!i,
+        },
+        prefer_future => {
+            type => SCALAR,
+            optional => 1,
+            regex => qr!^[01]$!,
+        },
+        time_zone => {
+            type => SCALAR,
+            optional => 1,
+            callbacks => {
+                'valid timezone' => sub
+                {
+                    eval { DateTime::TimeZone->new(name => shift) };
+                    !$@;
+                }
+            }
+        },
+        daytime => {
+            type => HASHREF,
+            optional => 1,
+        },
+    });
 }
 
 sub _init_vars
@@ -133,6 +150,7 @@ sub parse_datetime
         my ($day, $month, $year) = map { $bits[$separated_indices->{$_}] } qw(d m y);
 
         if (not defined $day && defined $month && defined $year) {
+            $self->_set_failure;
             $self->_set_error("('format' parameter invalid)");
             return $self->_get_datetime_object;
         }
@@ -140,9 +158,8 @@ sub parse_datetime
         if ($year > $century) { $century-- };
         if (length $year == 2) { $year = "$century$year" };
 
-        if (not $self->SUPER::_valid_date(day => $day)
-             && $self->SUPER::_valid_date(month => $month)
-             && $self->SUPER::_valid_date(year => $year)) {
+        unless (check_date($year, $month, $day)) {
+            $self->_set_failure;
             $self->_set_error("(invalid date)");
             return $self->_get_datetime_object;
         }
@@ -176,11 +193,13 @@ sub _parse_init
     my $self = shift;
 
     if (@_ > 1) {
+        validate(@_, { string => 1 });
         my %opts             = @_;
         $self->{Date_string} = $opts{string};
         (undef)              = $opts{debug}; # legacy
     }
     else {
+        validate_pos(@_, 1);
         ($self->{Date_string}) = @_;
     }
 
@@ -577,6 +596,7 @@ valuable suggestions & patches:
  Jonny Schulz
  Jesse Vincent
  Jason May
+ Pat Kale
 
 =head1 SEE ALSO
 
